Index — Poezio 0.9-dev documentation

# Index – G

gateway get_base64_from_file() (in module common) get_conversation_messages() (plugin.PluginAPI method) get_local_time() (in module common) get_mucnick() (slixmpp.Message method) get_mucroom() (slixmpp.Message method) get_os_info() (in module common) get_output_of_command() (in module common) get_parent_thread() (slixmpp.Message method) | get_priority() (slixmpp.Presence method) get_query() (slixmpp.Iq method) get_type() (slixmpp.Message method) (slixmpp.Presence method) get_utc_time() (in module common) go_to_previous_tab_on_alt_number GPG gpg (module) group_corrections